==> ejc-cost-api-3.0.0-20201209.075328-5-sources.jar: com/ejianc/business/cost/vo/ShareDetailVO.java <==
package com.ejianc.business.cost.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 成本分摊费用明细
 * 
 * @author generator
 * 
 */
public class ShareDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long shareId; // 主表主键ID
    private java.lang.Long sourceId; // 来源单据主键ID
    private java.lang.String path; // 前端跳转路径
    private java.lang.String name; // 费用项
    private java.lang.String billType; // 单据类型名称
    private java.lang.String billCode; // 单据编号
    private java.util.Date happenDate; // 发生日期
    private java.math.BigDecimal happenMny; // 发生成本
    private java.lang.String subjectFlag; // 是否关联成本科目 0-是，1-否
    private java.lang.String memo; // 备注
    private java.lang.Integer billState; // 单据状态（审批必须字段）
    private java.lang.String createUserName; // 创建人名称
    

    /**
     * 主表主键ID
     */
    public java.lang.Long getShareId() {
        return shareId;
    }

    /**
     * 主表主键ID
     */
    public void setShareId(java.lang.Long shareId) {
        this.shareId = shareId;
    }
    /**
     * 来源单据主键ID
     */
    public java.lang.Long getSourceId() {
        return sourceId;
    }

    /**
     * 来源单据主键ID
     */
    public void setSourceId(java.lang.Long sourceId) {
        this.sourceId = sourceId;
    }
    /**
     * 前端跳转路径
     */
    public java.lang.String getPath() {
        return path;
    }

    /**
     * 前端跳转路径
     */
    public void setPath(java.lang.String path) {
        this.path = path;
    }
    /**
     * 费用项
     */
    public java.lang.String getName() {
        return name;
    }

    /**
     * 费用项
     */
    public void setName(java.lang.String name) {
        this.name = name;
    }
    /**
     * 单据类型名称
     */
    public java.lang.String getBillType() {
        return billType;
    }

    /**
     * 单据类型名称
     */
    public void setBillType(java.lang.String billType) {
        this.billType = billType;
    }
    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 发生日期
     */
    public java.util.Date getHappenDate() {
        return happenDate;
    }

    /**
     * 发生日期
     */
    public void setHappenDate(java.util.Date happenDate) {
        this.happenDate = happenDate;
    }
    /**
     * 发生成本
     */
    public java.math.BigDecimal getHappenMny() {
        return happenMny;
    }

    /**
     * 发生成本
     */
    public void setHappenMny(java.math.BigDecimal happenMny) {
        this.happenMny = happenMny;
    }
    /**
     * 是否关联成本科目 0-是，1-否
     */
    public java.lang.String getSubjectFlag() {
        return subjectFlag;
    }

    /**
     * 是否关联成本科目 0-是，1-否
     */
    public void setSubjectFlag(java.lang.String subjectFlag) {
        this.subjectFlag = subjectFlag;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    /**
     * 单据状态（审批必须字段）
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态（审批必须字段）
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 创建人名称
     */
    public java.lang.String getCreateUserName() {
        return createUserName;
    }

    /**
     * 创建人名称
     */
    public void setCreateUserName(java.lang.String createUserName) {
        this.createUserName = createUserName;
    }
    
}

==> ejc-cost-api-3.0.0-20201216.033737-15-sources.jar: com/ejianc/business/cost/vo/ShareDetailVO.java <==
package com.ejianc.business.cost.vo;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 成本分摊费用明细
 * 
 * @author generator
 * 
 */
public class ShareDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long shareId; // 主表主键ID
    private java.lang.Long sourceId; // 来源单据主键ID
    private java.lang.String path; // 前端跳转路径
    private java.lang.String name; // 费用项
    private java.lang.String billType; // 单据类型名称
    private java.lang.String billCode; // 单据编号
    private java.lang.String happenDate; // 发生日期
    private java.math.BigDecimal happenMny; // 发生成本
    private java.math.BigDecimal happenTaxMny; // 发生成本（含税）
    private Boolean subjectFlag; // 是否关联成本科目 0-是，1-否
    private java.lang.String memo; // 备注
    private java.lang.Integer billState; // 单据状态（审批必须字段）
    private java.lang.String createUserName; // 创建人名称

    public BigDecimal getHappenTaxMny() {
        return happenTaxMny;
    }

    public void setHappenTaxMny(BigDecimal happenTaxMny) {
        this.happenTaxMny = happenTaxMny;
    }

    /**
     * 主表主键ID
     */
    public java.lang.Long getShareId() {
        return shareId;
    }

    /**
     * 主表主键ID
     */
    public void setShareId(java.lang.Long shareId) {
        this.shareId = shareId;
    }
    /**
     * 来源单据主键ID
     */
    public java.lang.Long getSourceId() {
        return sourceId;
    }

    /**
     * 来源单据主键ID
     */
    public void setSourceId(java.lang.Long sourceId) {
        this.sourceId = sourceId;
    }
    /**
     * 前端跳转路径
     */
    public java.lang.String getPath() {
        return path;
    }

    /**
     * 前端跳转路径
     */
    public void setPath(java.lang.String path) {
        this.path = path;
    }
    /**
     * 费用项
     */
    public java.lang.String getName() {
        return name;
    }

    /**
     * 费用项
     */
    public void setName(java.lang.String name) {
        this.name = name;
    }
    /**
     * 单据类型名称
     */
    public java.lang.String getBillType() {
        return billType;
    }

    /**
     * 单据类型名称
     */
    public void setBillType(java.lang.String billType) {
        this.billType = billType;
    }
    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 发生日期
     */
    public String getHappenDate() {
        return happenDate;
    }

    public void setHappenDate(String happenDate) {
        this.happenDate = happenDate;
    }

    /**
     * 发生成本
     */
    public java.math.BigDecimal getHappenMny() {
        return happenMny;
    }

    /**
     * 发生成本
     */
    public void setHappenMny(java.math.BigDecimal happenMny) {
        this.happenMny = happenMny;
    }
    /**
     * 是否关联成本科目 0-是，1-否
     */
    public Boolean getSubjectFlag() {
        return subjectFlag;
    }

    public void setSubjectFlag(Boolean subjectFlag) {
        this.subjectFlag = subjectFlag;
    }

    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    /**
     * 单据状态（审批必须字段）
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态（审批必须字段）
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 创建人名称
     */
    public java.lang.String getCreateUserName() {
        return createUserName;
    }

    /**
     * 创建人名称
     */
    public void setCreateUserName(java.lang.String createUserName) {
        this.createUserName = createUserName;
    }
    
}
